<!-- Important: This file has been automatically generated by generate_example_docs.py. Do not edit this file directly! -->


| [:arrow_left: Back to the main documentation](../README.md) | [:arrow_left: Go back to part 2](spatialparams.md) | [:arrow_right: Continue with part 4](main.md) |
|---|---|---:|



# Model (`TypeTag`) and property specializations (`properties.hh`)

This file contains the __property definitions__ which configure
the model and discretization method (at compile time). This file
implements three models: a common base model `NetworkTissueModel`,
and the sub-domain models `NetworkTransportModel` and `TissueTransportModel`
that inherit some of the basic properties from the common ancestor `NetworkTissueModel`.
By specializing properties for a model tag, every class that knows
the model tag can extract these properties at compile time. (In C++ speak, the
template structs that are specialized for different types are called "traits".)


<details open>
<summary><b>Click to hide/show the file documentation</b> (or inspect the [source code](../properties.hh))</summary>


### Include headers

```cpp
// 3d Cartesian grid implementation
#include <dune/grid/yaspgrid.hh>
// 1d in 3d embedded network grid implementation
#include <dune/foamgrid/foamgrid.hh>
// properties
#include <dumux/common/properties.hh>
// dof mapper that reorders dofs for optimal matrix pattern
#include <dumux/common/reorderingdofmapper.hh>
// discretization method
#include <dumux/discretization/cctpfa.hh>
// model equations
#include <dumux/porousmediumflow/tracer/model.hh>
// effective diffusion coefficient model
#include <dumux/material/fluidmatrixinteractions/diffusivityconstanttortuosity.hh>
// general multidomain traits
#include <dumux/multidomain/traits.hh>
// 1d-3d coupling manager with surface average operator
#include <dumux/multidomain/embedded/couplingmanager1d3d_average.hh>

#include "spatialparams.hh"
#include "problem.hh"
#include "tracerfluidsystem.hh"
```


## Common properties of both models

```cpp
namespace Dumux::Properties {

// inheriting all properties from the tracer model (advection-diffusion equation)
// and inheriting all properties from the cell-centered finite volume discretization with two-point flux approximation
namespace TTag { struct NetworkTissueModel { using InheritsFrom = std::tuple<Tracer, CCTpfaModel>; }; }

// caching options, enabling caching uses more memory but is faster in terms of runtime
template<class TypeTag> struct EnableGridGeometryCache<TypeTag, TTag::NetworkTissueModel> { static constexpr bool value = true; };
template<class TypeTag> struct EnableGridVolumeVariablesCache<TypeTag, TTag::NetworkTissueModel> { static constexpr bool value = true; };
template<class TypeTag> struct EnableGridFluxVariablesCache<TypeTag, TTag::NetworkTissueModel> { static constexpr bool value = true; };
template<class TypeTag> struct SolutionDependentAdvection<TypeTag, TTag::NetworkTissueModel> { static constexpr bool value = false; };
template<class TypeTag> struct SolutionDependentMolecularDiffusion<TypeTag, TTag::NetworkTissueModel> { static constexpr bool value = false; };
template<class TypeTag> struct SolutionDependentHeatConduction<TypeTag, TTag::NetworkTissueModel> { static constexpr bool value = false; };

// Set the fluid system (see `tracerfluidsystem.hh`)
template<class TypeTag>
struct FluidSystem<TypeTag, TTag::NetworkTissueModel>
{ using type = TracerFluidSystem<double>; };

// Use molar balances and a mole fraction as primary variable
template<class TypeTag>
struct UseMoles<TypeTag, TTag::NetworkTissueModel>
{ static constexpr bool value = true; };

} // end namespace Dumux::Properties
```


## Network transport model

```cpp
namespace Dumux::Properties {

namespace TTag { struct NetworkTransportModel { using InheritsFrom = std::tuple<NetworkTissueModel>; }; }

// Set the grid type
template<class TypeTag>
struct Grid<TypeTag, TTag::NetworkTransportModel>
{ using type = Dune::FoamGrid<1, 3>; };

// Set the problem property
template<class TypeTag>
struct Problem<TypeTag, TTag::NetworkTransportModel>
{ using type = NetworkTransportProblem<TypeTag>; };

// Set the spatial parameters
template<class TypeTag>
struct SpatialParams<TypeTag, TTag::NetworkTransportModel>
{ using type = NetworkSpatialParams<GetPropType<TypeTag, Properties::GridGeometry>, double>; };

// if we have pt scotch use the reordering dof mapper to optimally sort the dofs (cc)
template<class TypeTag>
struct GridGeometry<TypeTag, TTag::NetworkTransportModel>
{
private:
    static constexpr bool enableCache = getPropValue<TypeTag, Properties::EnableGridGeometryCache>();
    using GridView = typename GetPropType<TypeTag, Properties::Grid>::LeafGridView;
    using ElementMapper = ReorderingDofMapper<GridView>;
    using VertexMapper = Dune::MultipleCodimMultipleGeomTypeMapper<GridView>;
    using MapperTraits = DefaultMapperTraits<GridView, ElementMapper, VertexMapper>;
public:
    using type = CCTpfaFVGridGeometry<GridView, enableCache, CCTpfaDefaultGridGeometryTraits<GridView, MapperTraits>>;
};

template<class Scalar>
class EffectiveDiffusionTissuePVS
{
public:
    template<class VolumeVariables>
    static Scalar effectiveDiffusionCoefficient(const VolumeVariables& volVars,
                                                const int phaseIdx,
                                                const int compIdxI,
                                                const int compIdxJ)
    {
        const Scalar diffCoeff = volVars.diffusionCoefficient(phaseIdx, compIdxI, compIdxJ);
        return volVars.porosity() * diffCoeff;
    }
};

template<class TypeTag>
struct EffectiveDiffusivityModel<TypeTag, TTag::NetworkTransportModel>
{ using type = EffectiveDiffusionTissuePVS<double>; };

} // end namespace Dumux::Properties
```


## Tissue transport model

```cpp
namespace Dumux::Properties {

namespace TTag { struct TissueTransportModel { using InheritsFrom = std::tuple<NetworkTissueModel>; }; }

// Set the grid type
template<class TypeTag>
struct Grid<TypeTag, TTag::TissueTransportModel>
{ using type = Dune::YaspGrid<3, Dune::EquidistantOffsetCoordinates<double, 3>>; };

// Set the problem property
template<class TypeTag>
struct Problem<TypeTag, TTag::TissueTransportModel>
{ using type = TissueTransportProblem<TypeTag>; };

// Set the spatial parameters
template<class TypeTag>
struct SpatialParams<TypeTag, TTag::TissueTransportModel>
{ using type = TissueSpatialParams<GetPropType<TypeTag, Properties::GridGeometry>, double>; };

template<class Scalar>
class EffectiveDiffusionTissue
{
public:
    template<class VolumeVariables>
    static Scalar effectiveDiffusionCoefficient(const VolumeVariables& volVars,
                                                const int phaseIdx,
                                                const int compIdxI,
                                                const int compIdxJ)
    {
        static const Scalar tau = getParam<Scalar>("Tissue.SpatialParams.Tortuosity");
        const Scalar diffCoeff = volVars.diffusionCoefficient(phaseIdx, compIdxI, compIdxJ);
        return tau * volVars.porosity() * diffCoeff;
    }
};

// effective diffusivity model
template<class TypeTag>
struct EffectiveDiffusivityModel<TypeTag, TTag::TissueTransportModel>
{ using type = EffectiveDiffusionTissue<double>; };

} // end namespace Dumux::Properties
```


## Multi-domain coupling

```cpp
namespace Dumux::Properties {

using CouplingTransport = Embedded1d3dCouplingManager<MultiDomainTraits<
    Properties::TTag::TissueTransportModel, Properties::TTag::NetworkTransportModel>,
    Embedded1d3dCouplingMode::Average
>;

// tell the tissue sub-model about the coupling
template<class TypeTag> struct CouplingManager<TypeTag, TTag::TissueTransportModel> { using type = CouplingTransport; };
template<class TypeTag> struct PointSource<TypeTag, TTag::TissueTransportModel> { using type = CouplingTransport::PointSourceTraits::template PointSource<0>; };
template<class TypeTag> struct PointSourceHelper<TypeTag, TTag::TissueTransportModel> { using type = CouplingTransport::PointSourceTraits::template PointSourceHelper<0>; };

// tell the network sub-model about the coupling
template<class TypeTag> struct CouplingManager<TypeTag, TTag::NetworkTransportModel> { using type = CouplingTransport; };
template<class TypeTag> struct PointSource<TypeTag, TTag::NetworkTransportModel> { using type = CouplingTransport::PointSourceTraits::template PointSource<1>; };
template<class TypeTag> struct PointSourceHelper<TypeTag, TTag::NetworkTransportModel> { using type = CouplingTransport::PointSourceTraits::template PointSourceHelper<1>; };

} // end namespace Dumux::Properties
```


</details>


| [:arrow_left: Back to the main documentation](../README.md) | [:arrow_left: Go back to part 2](spatialparams.md) | [:arrow_right: Continue with part 4](main.md) |
|---|---|---:|

